/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef BACKPROJECTEDIMAGE_H

#define BACKPROJECTEDIMAGE_H

#include <grale/vector2d.h>
#include <grale/triangulation.h>
#include <grale/triangle2d.h>
#include <errut/errorbase.h>
#include <vector>
#include <list>

namespace grale
{
	class ImagesData;
	class GravitationalLens;
	class GridFunction;
}

class BackProjectedImage : public errut::ErrorBase
{
public:
	BackProjectedImage();
	~BackProjectedImage();
	bool init(const grale::ImagesData &imageData,
		  int imageNumber,
		  const grale::GravitationalLens &lens,
		  double Ds, double Dds);
	bool calculateTheta(grale::Vector2D<double> beta, 
			    grale::Vector2D<double> &theta,
			    int numIterations = 20,
			    int numIterations2 = 4);
	bool calculateBeta(grale::Vector2D<double> theta,
	                   grale::Vector2D<double> &beta);
	grale::Vector2D<double> getSourceTopRight() const				{ return m_sourceTopRight; }
	grale::Vector2D<double> getSourceBottomLeft() const				{ return m_sourceBottomLeft; }
	grale::Vector2D<double> getImageTopRight() const				{ return m_imageTopRight; }
	grale::Vector2D<double> getImageBottomLeft() const				{ return m_imageBottomLeft; }

	grale::GridFunction *createSourceGrid(grale::Vector2D<double> bottomLeft, grale::Vector2D<double> topRight,
	                                      int width, int height);
	grale::GridFunction *createImageGrid(grale::Vector2D<double> bottomLeft, grale::Vector2D<double> topRight,
	                                      int width, int height);
private:
	grale::GravitationalLens *m_pLens;
	std::vector<grale::Vector2D<double> > m_thetaPoints, m_betaPoints;
	std::vector<double> m_thetaIntens, m_betaIntens;
	std::vector<grale::TriangleIndices> m_triangles;
	double m_Ds, m_Dds;
	grale::Vector2D<double> m_sourceBottomLeft, m_sourceTopRight;
	grale::Vector2D<double> m_imageBottomLeft, m_imageTopRight;
	std::list<grale::Triangle2DPlus<double> > m_betaTriangles;
	std::list<grale::Triangle2DPlus<double> > m_thetaTriangles;
};

#endif // BACKPROJECTEDIMAGE_H

