/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef IMAGESDATAWIDGET_H

#define IMAGESDATAWIDGET_H

#include <grale/vector2d.h>
#include <errut/errorbase.h>
#include <q3table.h>
#include <vector>
#include <string>

namespace grale
{
	class ImagesData;
	class GravitationalLens;
}

class ImageStack;
class ImageStackControlWidget;
class MainWidget;

class ImagesDataWidget : public Q3Table, public errut::ErrorBase
{
	Q_OBJECT;
public:
	ImagesDataWidget(QWidget *pParent);
	~ImagesDataWidget();

	bool init(double Ds, double Dds);
	bool addImagesData(const std::string &fileName, const std::string &name, const grale::GravitationalLens &lens);
	void clear();
	void clearWidgets();
	void createWidgets(QWidget *pParent, ImageStackControlWidget *pGlobalSourceControl,
			   ImageStackControlWidget *pGlobalImageControl, int minRes,
			   const MainWidget *w);
	int getNumberOfDataSets() const							{ return m_imagesDataSet.size(); }
	bool hasWidgets() const								{ if (m_imageStackWidgets.empty()) return false; return true; }
signals:
	void signalWidgetCreated(QWidget *pW);
private:
	void setCommonSourceRegion();
	void calculateResolution(grale::Vector2D<double> bottomLeft, grale::Vector2D<double> topRight, int *xRes, int *yRes);

	std::vector<grale::ImagesData *> m_imagesDataSet;
	std::vector<ImageStack *> m_imageStacks;
	double m_Ds, m_Dds;
	bool m_initialized;
	std::list<QWidget *> m_imageStackWidgets;
	int m_resolution;
	grale::Vector2D<double> m_sourceBottomLeft, m_sourceTopRight;
};

#endif // IMAGESDATAWIDGET_H

