/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef IMAGESTACK_H

#define IMAGESTACK_H

#include <grale/vector2d.h>
#include <errut/errorbase.h>
#include <vector>
#include <utility>

namespace grale
{
	class GridFunction;
}

class BackProjectedImage;

class ImageStack : public errut::ErrorBase
{
public:
	ImageStack();
	~ImageStack();
	void clear();
	void addImage(BackProjectedImage *pImage, bool deleteImage = true);
	bool removeImage(int index);
	void setSourceRegion(grale::Vector2D<double> bottomLeft, grale::Vector2D<double> topRight);	
	bool setSourceRegion(int index);
	void setSourceRegionExtremes();
	void setImageRegion(grale::Vector2D<double> bottomLeft, grale::Vector2D<double> topRight);	
	bool setImageRegion(int index);
	void setImageRegionExtremes();
	bool renderSources(int width, int height);
	bool renderImages(int width, int height);
	const grale::GridFunction *getSourceGrid(int index) const;
	const grale::GridFunction *getImageGrid(int index) const;
	bool calculateTheta(int index, grale::Vector2D<double> beta, grale::Vector2D<double> &theta, int numIterations = 100);
	bool calculateBeta(int index, grale::Vector2D<double> theta, grale::Vector2D<double> &beta);
	grale::Vector2D<double> getSourceBottomLeft() const					{ return m_sourceBottomLeft; }
	grale::Vector2D<double> getSourceTopRight() const					{ return m_sourceTopRight; }
	grale::Vector2D<double> getImageBottomLeft() const					{ return m_imageBottomLeft; }
	grale::Vector2D<double> getImageTopRight() const					{ return m_imageTopRight; }
private:
	bool renderInternal(std::vector<grale::GridFunction *> &grids, grale::Vector2D<double> bottomLeft,
			    grale::Vector2D<double> topRight, bool renderAll, int width, int height, bool source);
	
	std::vector<std::pair<BackProjectedImage *, bool> > m_imageStack;
	std::vector<grale::GridFunction *> m_sourceGrids;
	std::vector<grale::GridFunction *> m_imageGrids;
	grale::Vector2D<double> m_sourceBottomLeft, m_sourceTopRight;
	grale::Vector2D<double> m_imageBottomLeft, m_imageTopRight;
	bool m_renderAllSources;
	bool m_renderAllImages;
};

#endif // IMAGESTACK_H
