/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "imagestackcontrolwidget.h"
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qspinbox.h>
#include <qlineedit.h>
#include <qvalidator.h>
#include <qlayout.h>
//Added by qt3to4:
#include <Q3HBoxLayout>
#include <Q3VBoxLayout>
#include <Q3Frame>
#include <iostream>

ImageStackControlWidget::ImageStackControlWidget(QWidget *pParent) : Q3Frame(pParent)
{
	// create controls
	m_pFont = new QFont("Courier",7);

	m_pRGBCheckBox = new QCheckBox(this);
	m_pRGBCheckBox->setChecked(true);

	m_pGrayIndexBox = createIndexBox(qRgb(224,224,224));
	m_pRIndexBox = createIndexBox(qRgb(255,224,224));
	m_pGIndexBox = createIndexBox(qRgb(224,255,224));
	m_pBIndexBox = createIndexBox(qRgb(224,224,255));
	m_pSetGrayButton = new QPushButton("Gray", this);
	m_pSetRGBButton = new QPushButton("RGB", this);

	m_pValidator = new QDoubleValidator(this);
	m_pGrayMinEdit = createMinMaxEdit(qRgb(224,224,224));
	m_pGrayMaxEdit = createMinMaxEdit(qRgb(224,224,224));
	m_pRedMinEdit = createMinMaxEdit(qRgb(255,224,224));
	m_pRedMaxEdit = createMinMaxEdit(qRgb(255,224,224));
	m_pGreenMinEdit = createMinMaxEdit(qRgb(224,255,224));
	m_pGreenMaxEdit = createMinMaxEdit(qRgb(224,255,224));
	m_pBlueMinEdit = createMinMaxEdit(qRgb(224,224,255));
	m_pBlueMaxEdit = createMinMaxEdit(qRgb(224,224,255));

	Q3VBoxLayout *pV0Layout = new Q3VBoxLayout(this);
	
//	pV0Layout->addStretch(1);
	Q3HBoxLayout *pH0Layout = new Q3HBoxLayout(pV0Layout);
//	pV0Layout->addStretch(1);

	pH0Layout->addStretch(1);
	pH0Layout->addSpacing(20);
	Q3HBoxLayout *pGrayLayout = new Q3HBoxLayout(pH0Layout);
	pH0Layout->addSpacing(20);
	Q3HBoxLayout *pRGBLayout = new Q3HBoxLayout(pH0Layout);
	pH0Layout->addSpacing(20);
	pH0Layout->addStretch(1);

	Q3VBoxLayout *pVLayout = new Q3VBoxLayout(pGrayLayout);

	pVLayout->addWidget(m_pSetGrayButton);

	pVLayout = new Q3VBoxLayout(pGrayLayout);
	pVLayout->addWidget(m_pGrayIndexBox);
	pVLayout->addWidget(m_pGrayMinEdit);
	pVLayout->addWidget(m_pGrayMaxEdit);

	pVLayout = new Q3VBoxLayout(pRGBLayout);
	pVLayout->addWidget(m_pSetRGBButton);

	pVLayout = new Q3VBoxLayout(pRGBLayout);
	pVLayout->addWidget(m_pRIndexBox);
	pVLayout->addWidget(m_pRedMinEdit);
	pVLayout->addWidget(m_pRedMaxEdit);

	pVLayout = new Q3VBoxLayout(pRGBLayout);
	pVLayout->addWidget(m_pGIndexBox);
	pVLayout->addWidget(m_pGreenMinEdit);
	pVLayout->addWidget(m_pGreenMaxEdit);

	pVLayout = new Q3VBoxLayout(pRGBLayout);
	pVLayout->addWidget(m_pBIndexBox);
	pVLayout->addWidget(m_pBlueMinEdit);
	pVLayout->addWidget(m_pBlueMaxEdit);

	pVLayout = new Q3VBoxLayout(pRGBLayout);
	pVLayout->addWidget(m_pRGBCheckBox);

	m_pGrayIndexBox->setValue(0);
	m_pRIndexBox->setValue(0);
	m_pGIndexBox->setValue(1);
	m_pBIndexBox->setValue(2);

	m_pGrayMinEdit->setText("0");
	m_pRedMinEdit->setText("0");
	m_pGreenMinEdit->setText("0");
	m_pBlueMinEdit->setText("0");
	m_pGrayMaxEdit->setText("1");
	m_pRedMaxEdit->setText("1");
	m_pGreenMaxEdit->setText("1");
	m_pBlueMaxEdit->setText("1");

	QObject::connect(m_pSetGrayButton, SIGNAL(clicked()), this, SLOT(onGrayButtonPressed()));
	QObject::connect(m_pSetRGBButton, SIGNAL(clicked()), this, SLOT(onRGBButtonPressed()));
}

ImageStackControlWidget::~ImageStackControlWidget()
{
}

QSpinBox *ImageStackControlWidget::createIndexBox(QRgb bgCol)
{
	QSpinBox *pSpinBox = new QSpinBox(-1, 100, 1, this);

	pSpinBox->setEraseColor(QColor(bgCol));
	pSpinBox->setFont(*m_pFont);

	return pSpinBox;
}

QLineEdit *ImageStackControlWidget::createMinMaxEdit(QRgb bgCol)
{
	QLineEdit *pLineEdit = new QLineEdit(this);

	pLineEdit->setEraseColor(QColor(bgCol));
	pLineEdit->setValidator(m_pValidator);
	pLineEdit->setFont(*m_pFont);

	return pLineEdit;
}

void ImageStackControlWidget::onRGBButtonPressed()
{
	int Rindex = m_pRIndexBox->value();
	int Gindex = m_pGIndexBox->value();
	int Bindex = m_pBIndexBox->value();
	
	double Rmin = m_pRedMinEdit->text().toDouble();
	double Rmax = m_pRedMaxEdit->text().toDouble();
	
	if (m_pRGBCheckBox->isChecked())
	{
		m_pGreenMinEdit->setText(m_pRedMinEdit->text());
		m_pGreenMaxEdit->setText(m_pRedMaxEdit->text());
		m_pBlueMinEdit->setText(m_pRedMinEdit->text());
		m_pBlueMaxEdit->setText(m_pRedMaxEdit->text());
	}
	
	double Gmin = m_pGreenMinEdit->text().toDouble();
	double Gmax = m_pGreenMaxEdit->text().toDouble();
	double Bmin = m_pBlueMinEdit->text().toDouble();
	double Bmax = m_pBlueMaxEdit->text().toDouble();

	emit signalRGB(Rindex, Gindex, Bindex, Rmin, Rmax, Gmin, Gmax, Bmin, Bmax);
}

void ImageStackControlWidget::onGrayButtonPressed()
{
	int index = m_pGrayIndexBox->value();
	double min = m_pGrayMinEdit->text().toDouble();
	double max = m_pGrayMaxEdit->text().toDouble();
	emit signalGray(index, min, max);
}

