/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef IMAGESTACKCONTROLWIDGET_H

#define IMAGESTACKCONTROLWIDGET_H

#include <q3frame.h>

class QSpinBox;
class QLineEdit;
class QCheckBox;
class QPushButton;
class QDoubleValidator;
class QFont;

class ImageStackControlWidget : public Q3Frame
{
	Q_OBJECT;
public:
	ImageStackControlWidget(QWidget *pParent);
	~ImageStackControlWidget();
signals:
	void signalGray(int index, double min, double max);
	void signalRGB(int Rindex, int Gindex, int Bindex,
	            double Rmin, double Rmax,
		    double Gmin, double Gmax,
		    double Bmin, double Bmax);
public slots:
	void onGrayButtonPressed();
	void onRGBButtonPressed();
private:
	QSpinBox *createIndexBox(QRgb bgCol);
	QLineEdit *createMinMaxEdit(QRgb bgCol);

	QCheckBox *m_pRGBCheckBox;
	QSpinBox *m_pGrayIndexBox;
	QSpinBox *m_pRIndexBox;
	QSpinBox *m_pGIndexBox;
	QSpinBox *m_pBIndexBox;
	QPushButton *m_pSetGrayButton;
	QPushButton *m_pSetRGBButton;
	QLineEdit *m_pGrayMinEdit, *m_pGrayMaxEdit;
	QLineEdit *m_pRedMinEdit, *m_pRedMaxEdit;
	QLineEdit *m_pGreenMinEdit, *m_pGreenMaxEdit;
	QLineEdit *m_pBlueMinEdit, *m_pBlueMaxEdit;
	QDoubleValidator *m_pValidator;
	QFont *m_pFont;
};

#endif // IMAGESTACKCONTROLWIDGET_H

