/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef IMAGESTACKWIDGET_H

#define IMAGESTACKWIDGET_H

#include <errut/errorbase.h>
#include <q3scrollview.h>
//Added by qt3to4:
#include <QMouseEvent>

class ImageStack;
class MainWidget;

class ImageStackWidget : public Q3ScrollView, public errut::ErrorBase
{
	Q_OBJECT;
public:
	ImageStackWidget(QWidget *pParent, ImageStack *pImageStack, bool source, int imageIndex, const MainWidget *w);
	~ImageStackWidget();
	bool setGrayscale(int index);
	bool setRGB(int Rindex, int Gindex, int Bindex);
	void setGrayMinMax(double min, double max)					{ m_grayMax = max; m_grayMin = min; }
	void setRGBMinMax(double min, double max)					{ for (int i = 0 ; i < 3 ; i++) { m_rgbMin[i] = min; m_rgbMax[i] = max; } }
	void setRedMinMax(double min, double max)					{ m_rgbMin[0] = min; m_rgbMax[0] = max; }
	void setGreenMinMax(double min, double max)					{ m_rgbMin[1] = min; m_rgbMax[1] = max; }
	void setBlueMinMax(double min, double max)					{ m_rgbMin[2] = min; m_rgbMax[2] = max; }
signals:
	void signalPointSelected(int imageIndex, double x, double y, double h);
private:
	void drawContents(QPainter *p, int clipx, int clipy, int clipw, int cliph);
	void contentsMouseReleaseEvent(QMouseEvent *e);

	const MainWidget *m_pMainWidget;
	ImageStack *m_pImageStack;
	bool m_source;
	bool m_grayScale;
	int m_grayIndex;
	int m_redIndex, m_greenIndex, m_blueIndex;
	double m_grayMin, m_grayMax;
	double m_rgbMin[3], m_rgbMax[3];
	int m_imageIndex;

};

#endif // IMAGESTACKWIDGET_H
