/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef MAINWIDGET_H

#define MAINWIDGET_H

#include <grale/vector2d.h>
#include <errut/errorbase.h>
#include <serut/serializationinterface.h>
#include <q3mainwindow.h>
#include <qcolor.h>
//Added by qt3to4:
#include <QKeyEvent>
#include <QCloseEvent>
#include <utility>
#include <list>

class QCloseEvent;
class QWorkspace;
class QTabWidget;
class QWidget;
class Q3ListView;
class QLineEdit;
class QKeyEvent;
class Q3ListViewItem;
class ImageStackControlWidget;
class ImagesDataWidget;

namespace grale
{
	class GravitationalLens;
	class SerialInterface;
	class ImagesData;
}

class MainWidget : public Q3MainWindow, public errut::ErrorBase
{
	Q_OBJECT;
public:
	MainWidget();
	~MainWidget();
	void getPointGroupInfo(int imageIndex, std::list<std::pair<grale::Vector2D<double>, QRgb > > &points) const;
	void getTimeDelayInfo(int imageIndex, std::list<std::pair<grale::Vector2D<double>, QRgb > > &points) const;
public slots:
	void onPointGroupNew();
	void onPointGroupAdd();
	void onPointGroupLoad();
	void onPointGroupSave();
	void onPointGroupImport();
	void onPointGroupExport();
	void onQuit();
	void onImagesDataLoad();
	void onImagesDataClear();
	void onImagesDataView();
	void onImagesDataClearView();
	void onImagesDataViewCreated(QWidget *pW);
	void onPointSelected(int imageIndex, double x, double y, double h);
	void onLensLoad();
signals:
	void signalGroupInfoChanged();
private:
	void createMenu();
	void closeEvent(QCloseEvent *pEvt);
	void keyPressEvent(QKeyEvent *pEvt);
	void keyReleaseEvent(QKeyEvent *pEvt); 
	bool writeGroupInfo(serut::SerializationInterface &si);
	bool readGroupInfo(serut::SerializationInterface &si);
	Q3ListViewItem *addGroup(const QString &name, QRgb rgb);
	void addPoint(Q3ListViewItem *pParent, int imageIndex, double x, double y, double h);
	void addTimeDelay(int imageIndex, double x, double y, double h, double delay, QRgb rgb);
	void updateStatus();
	int addImagesDataPoint(grale::ImagesData &imgDat, int imageIndex, grale::Vector2D<double> point, double height);
		
	ImageStackControlWidget *m_pGlobalSourceControl;
	ImageStackControlWidget *m_pGlobalImageControl;
	ImagesDataWidget *m_pImagesDataWidget;
	//QWorkspace *m_pWorkspace;
	QTabWidget *m_pWorkspace;
	Q3ListView *m_pPointGroupWidget;
	Q3ListView *m_pTimeDelayWidget;
	QLineEdit *m_pLensWidget;
	grale::GravitationalLens *m_pLens;
	bool m_modified;
	double m_Ds, m_Dds;
	int m_resolution;

	bool m_keyControl, m_keyShift;
};

#endif // MAINWIDGET_H

