/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef POINTGROUPITEM_H

#define POINTGROUPITEM_H

#include <q3listview.h>
#include <qcolor.h>

class PointGroupItemBase : public Q3ListViewItem
{
public:
	enum PointGroupItemType { Group, Point };
protected:
	PointGroupItemBase(PointGroupItemType t, Q3ListViewItem *pParent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null) :  Q3ListViewItem(pParent, label1, label2, label3, label4, label5, label6, label7, label8)
											{ m_type = t; }
	PointGroupItemBase(PointGroupItemType t, Q3ListView *pParent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null) :  Q3ListViewItem(pParent, label1, label2, label3, label4, label5, label6, label7, label8)
											{ m_type = t; }
	~PointGroupItemBase()								{ }
public:
	PointGroupItemType getType() const						{ return m_type; }
private:
	PointGroupItemType m_type;
};

class PointGroupItemGroup : public PointGroupItemBase
{
public:
	PointGroupItemGroup(QRgb rgb, Q3ListView *pParent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null) : PointGroupItemBase(PointGroupItemBase::Group, pParent, label1, label2, label3, label4, label5, label6, label7, label8)		
											{ m_rgb = rgb; }
	~PointGroupItemGroup()								{ }
	QRgb getRgb() const								{ return m_rgb; }
private:
	QRgb m_rgb;
};

class PointGroupItemPoint : public PointGroupItemBase
{
public:
	PointGroupItemPoint(int image, double x, double y, double h, Q3ListViewItem *pParent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null) : PointGroupItemBase(PointGroupItemBase::Point, pParent, label1, label2, label3, label4, label5, label6, label7, label8)		
											{ m_image = image; m_x = x; m_y = y; m_h = h;}
	~PointGroupItemPoint()								{ }
	int getImageNumber() const							{ return m_image; }
	double getX() const								{ return m_x; }
	double getY() const								{ return m_y; }
	double getHeight() const							{ return m_h; }
private:
	int m_image;
	double m_x, m_y, m_h;
};

#endif // POINTGROUPITEM_H

