/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "sourceandimagewidget.h"
#include "imagestackwidget.h"
#include "imagestackcontrolwidget.h"
#include <qspinbox.h>
#include <qlayout.h>
//Added by qt3to4:
#include <Q3VBoxLayout>
#include <Q3Frame>
#include <Q3HBoxLayout>
#include <iostream>

SourceAndImageWidget::SourceAndImageWidget(QWidget *pParent, ImageStack *pImageStack, int imageIndex, const MainWidget *w) : Q3Frame(pParent)
{
	Q3HBoxLayout *pHLayout = new Q3HBoxLayout(this);
	Q3VBoxLayout *pV1Layout = new Q3VBoxLayout(pHLayout);
	Q3VBoxLayout *pV2Layout = new Q3VBoxLayout(pHLayout);

	m_pSourceWidget = new ImageStackWidget(this, pImageStack, true, imageIndex, w);
	m_pImageWidget = new ImageStackWidget(this, pImageStack, false, imageIndex, w);
	m_pSourceControl = new ImageStackControlWidget(this);
	m_pImageControl = new ImageStackControlWidget(this);

	pV1Layout->addWidget(m_pSourceWidget);
	pV1Layout->addWidget(m_pSourceControl);
	pV2Layout->addWidget(m_pImageWidget);
	pV2Layout->addWidget(m_pImageControl);

	QObject::connect(m_pSourceControl, SIGNAL(signalGray(int, double, double)), this, SLOT(slotSourceGray(int, double, double)));
	QObject::connect(m_pImageControl, SIGNAL(signalGray(int, double, double)), this, SLOT(slotImageGray(int, double, double)));
	QObject::connect(m_pSourceControl, SIGNAL(signalRGB(int, int, int, double, double, double, double, double, double)), this, SLOT(slotSourceRGB(int, int, int, double, double, double, double, double, double)));
	QObject::connect(m_pImageControl, SIGNAL(signalRGB(int, int, int, double, double, double, double, double, double)), this, SLOT(slotImageRGB(int, int, int, double, double, double, double, double, double)));
	QObject::connect(m_pSourceWidget, SIGNAL(signalPointSelected(int, double, double, double)), this, SLOT(slotPointSelected(int, double, double, double)));
	QObject::connect(m_pImageWidget, SIGNAL(signalPointSelected(int, double, double, double)), this, SLOT(slotPointSelected(int, double, double, double)));
}

SourceAndImageWidget::~SourceAndImageWidget()
{
}

void SourceAndImageWidget::slotSourceGray(int index, double min, double max)
{
	m_pSourceWidget->setGrayscale(index);
	m_pSourceWidget->setGrayMinMax(min, max);
	m_pSourceWidget->updateContents();
}

void SourceAndImageWidget::slotImageGray(int index, double min, double max)
{
	m_pImageWidget->setGrayscale(index);
	m_pImageWidget->setGrayMinMax(min, max);
	m_pImageWidget->updateContents();
}

void SourceAndImageWidget::slotSourceRGB(int Rindex, int Gindex, int Bindex,
			   double Rmin, double Rmax,
			   double Gmin, double Gmax,
			   double Bmin, double Bmax)
{
	m_pSourceWidget->setRGB(Rindex, Gindex, Bindex);
	m_pSourceWidget->setRedMinMax(Rmin, Rmax);
	m_pSourceWidget->setGreenMinMax(Gmin, Gmax);
	m_pSourceWidget->setBlueMinMax(Bmin, Bmax);
	m_pSourceWidget->updateContents();
}

void SourceAndImageWidget::slotImageRGB(int Rindex, int Gindex, int Bindex,
			  double Rmin, double Rmax,
			  double Gmin, double Gmax,
			  double Bmin, double Bmax)
{
	m_pImageWidget->setRGB(Rindex, Gindex, Bindex);
	m_pImageWidget->setRedMinMax(Rmin, Rmax);
	m_pImageWidget->setGreenMinMax(Gmin, Gmax);
	m_pImageWidget->setBlueMinMax(Bmin, Bmax);
	m_pImageWidget->updateContents();
}

void SourceAndImageWidget::slotPointSelected(int imageIndex, double x, double y, double h)
{
	emit signalPointSelected(imageIndex, x, y, h);
	m_pSourceWidget->updateContents();
	m_pImageWidget->updateContents();
}

void SourceAndImageWidget::slotGroupInfoChanged()
{
	m_pSourceWidget->updateContents();
	m_pImageWidget->updateContents();
}

