/*

  This file is a part of GRALEPS, a point selection utility to help
  create input data for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef SOURCEANDIMAGEWIDGET_H

#define SOURCEANDIMAGEWIDGET_H

#include <q3frame.h>
//Added by qt3to4:
#include <QPaintEvent>

class ImageStack;
class ImageStackWidget;
class ImageStackControlWidget;
class MainWidget;
class QPaintEvent;

class SourceAndImageWidget : public Q3Frame
{
	Q_OBJECT;
public:
	SourceAndImageWidget(QWidget *pParent, ImageStack *pImageStack, int imageIndex, const MainWidget *w);
	~SourceAndImageWidget();
public slots:
	void slotSourceGray(int index, double min, double max);
	void slotImageGray(int index, double min, double max);
	void slotSourceRGB(int Rindex, int Gindex, int Bindex,
			   double Rmin, double Rmax,
			   double Gmin, double Gmax,
			   double Bmin, double Bmax);
	void slotImageRGB(int Rindex, int Gindex, int Bindex,
			  double Rmin, double Rmax,
			  double Gmin, double Gmax,
			  double Bmin, double Bmax);
	void slotPointSelected(int imageIndex, double x, double y, double h);
	void slotGroupInfoChanged();
signals:
	void signalPointSelected(int imageIndex, double x, double y, double h);
private:	
	ImageStackWidget *m_pSourceWidget;
	ImageStackWidget *m_pImageWidget;
	ImageStackControlWidget *m_pSourceControl;
	ImageStackControlWidget *m_pImageControl;
};

#endif // SOURCEANDIMAGEWIDGET_H

